BasisPointsError

Enum BasisPointsError 

pub enum BasisPointsError {
    InvalidBasisPoints,
    ConversionFailed,
}
Errors returned by BasisPoints validation and conversions.

Variants



InvalidBasisPoints

Basis points must be less than or equal to 10_000.



ConversionFailed

Decimal could not be safely cast to the target integer type.